#!/usr/bin/env python3

from lxml import html
import requests
from bs4 import BeautifulSoup
import sys
import itertools
import genanki
import glob
import shutil
import os.path

origin_language = sys.argv[1].upper()
target_language = sys.argv[2].upper()


url = "https://www.goethe-verlag.com/book2/_VOCAB"

target_url = f"{url}/{origin_language}/{origin_language}{target_language}/"


def pad_number(n):
    if n < 10:
        return "0" + str(n)
    else:
        return str(n)


my_model = genanki.Model(
    1091735104,
    "Simple Model with Media",
    fields=[
        {"name": "Question"},
        {"name": "Answer"},
        {"name": "MyMedia"},  # ADD THIS
    ],
    templates=[
        {
            "name": "Card 1",
            "qfmt": "{{Question}}",  # AND THIS
            "afmt": '{{FrontSide}}<hr id="answer">{{Answer}}<br>{{MyMedia}}',
        },
    ],
)

my_deck = genanki.Deck(
    2059400110, f"Book2 {origin_language}-{target_language}"
)

MAX_LESSONS = 42

for i in range(1, MAX_LESSONS + 1):
    r = requests.get(f"{target_url}/{pad_number(i)}.HTM")
    soup = BeautifulSoup(r.content, "html.parser")
    words = str(soup.select("meta")[-1]).split('"')[1].split("| ")
    mp3s = [target_url + str(u).split('"')[1] for u in soup.select("source")]

    for w, m in zip(words, mp3s):

        filename = m.split("/")[-1]

        target_w, source_w = w.split(" - ")
        if not os.path.isfile(filename):
            dl_file = requests.get(m, stream=True)
            print(m)
            with open(filename, "wb") as out_file:
                shutil.copyfileobj(dl_file.raw, out_file)

        my_note = genanki.Note(
            model=my_model, fields=[source_w, target_w, f"[sound:{filename}]"]
        )

        my_deck.add_note(my_note)

my_package = genanki.Package(my_deck)
my_package.media_files = [m for m in glob.glob("*.mp3")]
my_package.write_to_file(f"book2_{origin_language}{target_language}.apkg")
